* {
  box-sizing: border-box;
}

body {
  font-family: Arial, Helvetica, sans-serif;
}

.navbar {
  background-color: lightslategray;
  font-size: 20px;
  color: white;
  padding: 8px 5px 8px 5px;
}

.navbar a {
  text-decoration: none;
  color: inherit;
}

.navbar-item {
  font-variant: small-caps;
  margin-left: 5px;
  margin-right: 25px;
}

.body-content {
  padding: 5px;
}

/* Style the header */
.header {
  background-color: #f1f1f1;
  padding: 30px;
  text-align: center;
  font-size: 35px;
}

/* Create two unequal columns that floats next to each other */
.column {
  float: left;
  padding: 10px;
}

.left {
  width: 25%;
}

.right {
  width: 75%;
}

/* Clear floats after the columns */
.row:after {
  content: "";
  display: table;
  clear: both;
}

/* Style the footer */
footer {
  background-color: #f1f1f1;
  padding: 10px;
  text-align: center;
  font-size: x-small;
}

table, th, td {
  border: 1px solid rgb(145, 145, 145);
  border-collapse: collapse;
  padding: 6px;
  font-size: small; 
}


th {
  height: 70px;
}
tr:nth-child(even) {background-color: #f2f2f2;}

/* unvisited link */
a:link {
  color: #3c444c; 
  text-decoration: none;
}

/* visited link */
a:visited {
  color: #3c444c; 
  text-decoration: none;
}

/* mouse over link */
a:hover {
  color: #3c444c; 
  text-decoration: underline;
}

/* selected link */
a:active {
  color: #3c444c;
  text-decoration: underline;
}

/* Tooltip container */
.tooltip {
  position: relative;
  display: inline-block;
  border-bottom: 1px dotted black; /* If you want dots under the hoverable text */
}

/* Tooltip text */
.tooltip .tooltiptext {
  visibility: hidden;
  width: 120px;
  font-size: 12px;
  background-color: black;
  color: #fff;
  text-align: center;
  padding: 5px 0;
  border-radius: 6px;
 
  /* Position the tooltip text - see examples below! */
  position: absolute;
  z-index: 1;
}

/* Show the tooltip text when you mouse over the tooltip container */
.tooltip:hover .tooltiptext {
  visibility: visible;
}

ul.flashes {
  background-color: yellow;
}